@@ -15,6 +15,8 @@
 import copy
 import unittest
 
+import json
+
 import six
 
 import warlock
@@ -39,6 +41,15 @@ complex_fixture = {
 }
 
 
+nameless_fixture = {
+    'properties': {
+        'name': {'type': 'string'},
+        'population': {'type': 'integer'},
+    },
+    'additionalProperties': False,
+}
+
+
 class TestCore(unittest.TestCase):
     def test_create_invalid_object(self):
         Country = warlock.model_factory(fixture)
@@ -94,6 +105,19 @@ class TestCore(unittest.TestCase):
         exc = warlock.InvalidOperation
         self.assertRaises(exc, sweden.update, {'population': 'N/A'})
         self.assertRaises(exc, sweden.update, {'overloard': 'Bears'})
+    
+    def test_naming(self):
+        Country = warlock.model_factory(fixture)
+        self.assertEqual(Country.__name__, 'Country')
+        
+        Country2 = warlock.model_factory(fixture, name='Country2')
+        self.assertEqual(Country2.__name__, 'Country2')
+        
+        nameless = warlock.model_factory(nameless_fixture)
+        self.assertEqual(nameless.__name__, 'Model')
+        
+        nameless2 = warlock.model_factory(nameless_fixture, name='Country3')
+        self.assertEqual(nameless2.__name__, 'Country3')
 
     def test_deepcopy(self):
         """Make sure we aren't leaking references."""
@@ -169,14 +193,17 @@ class TestCore(unittest.TestCase):
         sweden = Country(name='Sweden', population=9379116)
         sweden['name'] = 'Finland'
         self.assertEqual(
-            sweden.patch,
-            '[{"path": "/name", "value": "Finland", "op": "replace"}]')
+            json.loads(sweden.patch),
+            json.loads(
+                '[{"path": "/name", "value": "Finland", "op": "replace"}]'))
 
     def test_patch_drop_attribute(self):
         Country = warlock.model_factory(fixture)
         sweden = Country(name='Sweden', population=9379116)
         del sweden['name']
-        self.assertEqual(sweden.patch, '[{"path": "/name", "op": "remove"}]')
+        self.assertEqual(
+            json.loads(sweden.patch),
+            json.loads('[{"path": "/name", "op": "remove"}]'))
 
     def test_patch_reduce_operations(self):
         Country = warlock.model_factory(fixture)
@@ -184,13 +211,15 @@ class TestCore(unittest.TestCase):
 
         sweden['name'] = 'Finland'
         self.assertEqual(
-            sweden.patch,
-            '[{"path": "/name", "value": "Finland", "op": "replace"}]')
+            json.loads(sweden.patch),
+            json.loads(
+                '[{"path": "/name", "value": "Finland", "op": "replace"}]'))
 
         sweden['name'] = 'Norway'
         self.assertEqual(
-            sweden.patch,
-            '[{"path": "/name", "value": "Norway", "op": "replace"}]')
+            json.loads(sweden.patch),
+            json.loads(
+                '[{"path": "/name", "value": "Norway", "op": "replace"}]'))
 
     def test_patch_multiple_operations(self):
         Country = warlock.model_factory(fixture)
@@ -198,7 +227,12 @@ class TestCore(unittest.TestCase):
 
         sweden['name'] = 'Finland'
         sweden['population'] = 5387000
-        self.assertEqual(
-            sweden.patch,
+
+        self.assertEqual(len(json.loads(sweden.patch)), 2)
+
+        patches = json.loads(
             '[{"path": "/name", "value": "Finland", "op": "replace"}, '
             '{"path": "/population", "value": 5387000, "op": "replace"}]')
+
+        for patch in json.loads(sweden.patch):
+            self.assertTrue(patch in patches)
